==> process-rest-service-call-springboot-1.10.0.Final-sources.jar: org/acme/travels/UsersModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "users", name = "Users", hidden = true)
public class UsersModelInput implements Model, MapInput, MapInputId, MapOutput, MappableToModel<UsersModel> {

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.User traveller;

    public org.acme.travels.User getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.User traveller) {
        this.traveller = traveller;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "username")
    @javax.validation.Valid()
    private java.lang.String username;

    public java.lang.String getUsername() {
        return username;
    }

    public void setUsername(java.lang.String username) {
        this.username = username;
    }

    @Override()
    public UsersModel toModel() {
        UsersModel result = new UsersModel();
        result.setTraveller(getTraveller());
        result.setUsername(getUsername());
        return result;
    }
}

==> process-rest-service-call-springboot-1.14.1.Final-sources.jar: org/acme/travels/UsersModelInput.java <==
/*
 * Copyright 2020 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.acme.travels;

import org.kie.kogito.MapInput;
import org.kie.kogito.MapInputId;
import org.kie.kogito.MapOutput;
import java.util.Map;
import java.util.HashMap;
import org.kie.kogito.MappableToModel;
import org.kie.kogito.Model;

@org.kie.kogito.codegen.Generated(value = "kogito-codegen", reference = "users", name = "Users", hidden = true)
public class UsersModelInput implements Model, MapInput, MapInputId, MapOutput, MappableToModel<UsersModel> {

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "traveller")
    @javax.validation.Valid()
    private org.acme.travels.springboot.User traveller;

    public org.acme.travels.springboot.User getTraveller() {
        return traveller;
    }

    public void setTraveller(org.acme.travels.springboot.User traveller) {
        this.traveller = traveller;
    }

    @org.kie.kogito.codegen.VariableInfo(tags = "")
    @com.fasterxml.jackson.annotation.JsonProperty(value = "username")
    @javax.validation.Valid()
    private java.lang.String username;

    public java.lang.String getUsername() {
        return username;
    }

    public void setUsername(java.lang.String username) {
        this.username = username;
    }

    @Override()
    public UsersModel toModel() {
        UsersModel result = new UsersModel();
        result.setTraveller(getTraveller());
        result.setUsername(getUsername());
        return result;
    }
}
